use crate::controllers::{HttpResult, LibVirtReq};
use crate::extractors::group_vm_id_extractor::GroupVmIdExtractor;
use crate::libvirt_rest_structures::vm::VMInfo;
use actix_web::HttpResponse;

/// Get the list of groups
pub async fn list(client: LibVirtReq) -> HttpResult {
    let groups = match client.get_full_groups_list().await {
        Err(e) => {
            log::error!("Failed to get the list of groups! {e}");
            return Ok(HttpResponse::InternalServerError()
                .json(format!("Failed to get the list of groups! {e}")));
        }
        Ok(l) => l,
    };

    Ok(HttpResponse::Ok().json(groups))
}

/// Get information about a VM
pub async fn vm_info(vms_ids: GroupVmIdExtractor) -> HttpResult {
    let mut vms = Vec::new();
    for vm in vms_ids.0 {
        vms.push(VMInfo::from_domain(vm)?)
    }
    Ok(HttpResponse::Ok().json(vms))
}
